import matplotlib.pyplot as plt
from matplotlib import animation
from math import pi, sin


class BeatingCircle:
    def __init__(self, center, radius_min, radius_max, color):
        self.center = center
        self.radius_min = radius_min
        self.radius_max = radius_max
        self.color = color
        self.circle = None
        self.frames = None

    def animate(self, interval=100, frames=20, xlim=(0,1), ylim=(0,1)):
        assert frames > 1
        fig, ax = plt.subplots()
        ax.set(xlim=xlim, ylim=ylim)
        ax.set_aspect('equal')
        
        self.frames = frames
        self.circle = plt.Circle(self.center, self.radius_min, color=self.color)
        ax.add_patch(self.circle)
        
        anim = animation.FuncAnimation(fig, self.next_frame, frames=frames, repeat=True, interval=interval, blit=True)
        plt.show()

    def next_frame(self, i):
        d = 2 * pi * i / self.frames
        s = (1 + sin(d)) / 2
        self.circle.radius = self.radius_min + s * (self.radius_max - self.radius_min)
        return self.circle,


if __name__ == "__main__":
    bc = BeatingCircle((2, 3), 1, 2, 'r')
    bc.animate(20, 20, (-5, 5), (-5, 5))
    bc.animate(1, 300, (0, 10), (0, 10))
    bc.animate(1, 100, (-100, 100), (-100, 100))
    bc2 = BeatingCircle((2, 3), 1, 5, 'b')
    bc2.animate(1, 200, (-5, 5), (-5, 5))
